==> GlassConfigAPI-3.0.0-sources.jar: net/glasslauncher/mods/gcapi3/mixin/client/JoinMixin.java <==
package net.glasslauncher.mods.gcapi3.mixin.client;

import net.fabricmc.loader.api.FabricLoader;
import net.glasslauncher.mods.gcapi3.api.ConfigRoot;
import net.glasslauncher.mods.gcapi3.impl.GCCore;
import net.glasslauncher.mods.gcapi3.impl.object.ConfigCategoryHandler;
import net.glasslauncher.mods.gcapi3.impl.object.ConfigEntryHandler;
import net.glasslauncher.mods.networking.GlassNetworkHandler;
import net.glasslauncher.mods.networking.GlassNetworking;
import net.minecraft.class_118;
import net.minecraft.class_219;
import net.minecraft.class_433;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.lang.reflect.*;
import java.util.*;

@SuppressWarnings("deprecation")
@Mixin(class_219.class)
public class JoinMixin {
    @Inject(
            method = "onHello",
            at = @At("HEAD")
    )
    private void stationapi_onLoginSuccess(class_118 packet, CallbackInfo ci) {

        if(!((GlassNetworkHandler) this).glass_Networking$hasGlassNetworking()) {
            GCCore.MOD_CONFIGS.forEach((identifier, configRootEntry) -> recursiveTriggerVanillaBehavior(configRootEntry.configCategoryHandler()));
        }
    }

    @Unique
    private void recursiveTriggerVanillaBehavior(ConfigCategoryHandler configCategory) {
        configCategory.values.forEach((aClass, configBase) -> {
            if(configBase.getClass().isAssignableFrom(ConfigCategoryHandler.class)) {
                recursiveTriggerVanillaBehavior((ConfigCategoryHandler) configBase);
            }
            else {
                ((ConfigEntryHandler<?>) configBase).vanillaServerBehavior();
            }
        });
    }

    @Inject(
            method = "onDisconnected",
            at = @At("HEAD")
    )
    private void stationapi_onDropped(String reason, Object[] stacktrace, CallbackInfo ci) {
        onClientDisconnect();
    }

    @Inject(
            method = "onDisconnect",
            at = @At("HEAD")
    )
    private void stationapi_onKicked(class_433 packet, CallbackInfo ci) {
        onClientDisconnect();
    }

    @Unique
    private void onClientDisconnect() {
        GCCore.log("Unloading server synced config!");
        FabricLoader.getInstance().getEntrypointContainers(GCCore.NAMESPACE.getMetadata().getId(), Object.class).forEach((entrypointContainer -> {
            try {
                for (Field field : entrypointContainer.getEntrypoint().getClass().getDeclaredFields()) {
                    if (field.getAnnotation(ConfigRoot.class) == null) {
                        continue;
                    }
                    String configID = entrypointContainer.getProvider().getMetadata().getId() + ":" + field.getAnnotation(ConfigRoot.class).value();
                    GCCore.loadModConfig(entrypointContainer.getEntrypoint(), entrypointContainer.getProvider(), field, configID, null);
                }
            } catch (Exception e) {
                throw new RuntimeException(e);
            }
        }));
    }
}

==> GlassConfigAPI-3.2.0-sources.jar: net/glasslauncher/mods/gcapi3/mixin/client/JoinMixin.java <==
package net.glasslauncher.mods.gcapi3.mixin.client;

import net.fabricmc.loader.api.FabricLoader;
import net.glasslauncher.mods.gcapi3.api.ConfigRoot;
import net.glasslauncher.mods.gcapi3.impl.GCCore;
import net.glasslauncher.mods.gcapi3.impl.object.ConfigCategoryHandler;
import net.glasslauncher.mods.gcapi3.impl.object.ConfigEntryHandler;
import net.glasslauncher.mods.networking.GlassNetworking;
import net.minecraft.class_169;
import net.minecraft.class_219;
import net.minecraft.class_281;
import net.minecraft.class_433;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.lang.reflect.Field;

@SuppressWarnings("deprecation")
@Mixin(class_219.class)
public class JoinMixin {
    @Inject(
            method = "onHandshake",
            at = @At("HEAD")
    )
    private void onLoginSuccess(class_281 par1, CallbackInfo ci) {
    }

    @Unique
    private void recursiveTriggerVanillaUndoBehavior(ConfigCategoryHandler configCategory) {
        configCategory.values.forEach((aClass, configBase) -> {
            if(configBase.getClass().isAssignableFrom(ConfigCategoryHandler.class)) {
                recursiveTriggerVanillaUndoBehavior((ConfigCategoryHandler) configBase);
            }
            else {
                ((ConfigEntryHandler<?>) configBase).undoVanillaServerBehaviour();
            }
        });
    }

    @Inject(
            method = "onDisconnected",
            at = @At("HEAD")
    )
    private void onDropped(String reason, Object[] stacktrace, CallbackInfo ci) {
        onClientDisconnect();
    }

    @Inject(
            method = "onDisconnect",
            at = @At("HEAD")
    )
    private void onKicked(class_433 packet, CallbackInfo ci) {
        onClientDisconnect();
    }

    @Inject(
            method = "method_1646",
            at = @At("HEAD")
    )
    private void onDisconnect(class_169 par1, CallbackInfo ci) {
        onClientDisconnect();
    }

    @Unique
    private void onClientDisconnect() {
        GCCore.log("Unloading server synced config!");
        if(!GlassNetworking.serverHasNetworking()) {
            GCCore.MOD_CONFIGS.forEach((identifier, configRootEntry) -> recursiveTriggerVanillaUndoBehavior(configRootEntry.configCategoryHandler()));
        }
        FabricLoader.getInstance().getEntrypointContainers(GCCore.NAMESPACE.getMetadata().getId(), Object.class).forEach((entrypointContainer -> {
            try {
                for (Field field : entrypointContainer.getEntrypoint().getClass().getDeclaredFields()) {
                    if (field.getAnnotation(ConfigRoot.class) == null) {
                        continue;
                    }
                    String configID = entrypointContainer.getProvider().getMetadata().getId() + ":" + field.getAnnotation(ConfigRoot.class).value();
                    GCCore.loadModConfig(entrypointContainer.getEntrypoint(), entrypointContainer.getProvider(), field, configID, null);
                }
            } catch (Exception e) {
                throw new RuntimeException(e);
            }
        }));
    }
}
